import torch
import whisper


class Transcriber:
    def __init__(self):
        device = 'cuda' if torch.cuda.is_available() else 'cpu'
        self.model = whisper.load_model('large-v2', device=device, in_memory=True)

    def predict(self, path_audio_file):
        result = self.model.transcribe(path_audio_file, language='ar')
        return result


if __name__ == '__main__':
    res = Transcriber().predict('data/arabic_1m.m4a')
    print(res)
    """
    {
        'text': ' كان ولدهم أمي دوبوسي إنه بشع ما مشكلته التصميم وليس من الذهب آه روشي هل تفقدت الحظار العاملون هدونا ماذا أبي مؤكد هناك موظف لهذه الأشياء ولما لا تفعل حسناً لما أهتم بهذه الأشياء تافهة تظن أن العاملين المشتهدين شيئ تافه نعم آه كيرو الحبوب في مزارعنا هي الذهب الحقيقي والعاملون حسناً هم أهم شيء أمي رجاءً أهم شيء لي هو آه هذه دعوة عشاء الملك أوه أحتاج ملابس جديدة وكفا روشي لقد دللناك كثيراً لن تأتي العشاء الملك معنا لماذا كيرو الحبوب لقد فكرنا لبعض الوقت',
        'segments': [{'id': 0, 'seek': 0, 'start': 0.0, 'end': 2.0, 'text': ' كان ولدهم',
                      'tokens': [50364, 25961, 35525, 3215, 16095, 50464], 'temperature': 0.0,
                      'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 1, 'seek': 0, 'start': 2.0, 'end': 4.0, 'text': ' أمي دوبوسي إنه بشع',
                      'tokens': [50464, 5551, 2304, 1829, 11778, 37746, 41779, 1829, 36145, 3224, 4724, 8592, 3615,
                                 50564], 'temperature': 0.0, 'avg_logprob': -0.26228470770304635,
                      'compression_ratio': 1.841860465116279, 'no_speech_prob': 0.3708573281764984},
                     {'id': 2, 'seek': 0, 'start': 4.0, 'end': 6.0, 'text': ' ما مشكلته',
                      'tokens': [50564, 19446, 37893, 28820, 47395, 50664], 'temperature': 0.0,
                      'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 3, 'seek': 0, 'start': 6.0, 'end': 8.0, 'text': ' التصميم وليس من الذهب',
                      'tokens': [50664, 16712, 9381, 2304, 32640, 4032, 20292, 3794, 9154, 32545, 3224, 3555, 50764],
                      'temperature': 0.0, 'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 4, 'seek': 0, 'start': 8.0, 'end': 10.0, 'text': ' آه',
                      'tokens': [50764, 19753, 3224, 50864], 'temperature': 0.0, 'avg_logprob': -0.26228470770304635,
                      'compression_ratio': 1.841860465116279, 'no_speech_prob': 0.3708573281764984},
                     {'id': 5, 'seek': 0, 'start': 10.0, 'end': 12.0, 'text': ' روشي هل تفقدت الحظار',
                      'tokens': [50864, 12602, 2407, 8592, 1829, 8032, 1211, 6055, 5172, 28543, 2655, 21542, 19913,
                                 9640, 50964], 'temperature': 0.0, 'avg_logprob': -0.26228470770304635,
                      'compression_ratio': 1.841860465116279, 'no_speech_prob': 0.3708573281764984},
                     {'id': 6, 'seek': 0, 'start': 12.0, 'end': 14.0, 'text': ' العاملون هدونا',
                      'tokens': [50964, 18863, 10943, 1211, 11536, 8032, 3215, 2407, 8315, 51064], 'temperature': 0.0,
                      'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 7, 'seek': 0, 'start': 14.0, 'end': 16.0, 'text': ' ماذا أبي مؤكد هناك',
                      'tokens': [51064, 3714, 45636, 995, 5551, 21292, 3714, 33604, 4117, 3215, 34105, 4117, 51164],
                      'temperature': 0.0, 'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 8, 'seek': 0, 'start': 16.0, 'end': 18.0, 'text': ' موظف لهذه الأشياء',
                      'tokens': [51164, 3714, 2407, 19913, 5172, 46740, 24192, 16247, 8592, 1829, 16606, 51264],
                      'temperature': 0.0, 'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 9, 'seek': 0, 'start': 18.0, 'end': 20.0, 'text': ' ولما لا تفعل',
                      'tokens': [51264, 4032, 19528, 995, 20193, 6055, 5172, 30241, 51364], 'temperature': 0.0,
                      'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 10, 'seek': 0, 'start': 20.0, 'end': 22.0, 'text': ' حسناً لما أهتم بهذه الأشياء',
                      'tokens': [51364, 11331, 3794, 8315, 14111, 32767, 995, 5551, 3224, 39237, 39627, 24192, 16247,
                                 8592, 1829, 16606, 51464], 'temperature': 0.0, 'avg_logprob': -0.26228470770304635,
                      'compression_ratio': 1.841860465116279, 'no_speech_prob': 0.3708573281764984},
                     {'id': 11, 'seek': 0, 'start': 22.0, 'end': 24.0, 'text': ' تافهة',
                      'tokens': [51464, 6055, 31845, 3224, 3660, 51564], 'temperature': 0.0,
                      'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 12, 'seek': 0, 'start': 24.0, 'end': 26.0, 'text': ' تظن أن العاملين المشتهدين شيئ',
                      'tokens': [51564, 6055, 19913, 1863, 14739, 18863, 10943, 1211, 9957, 9673, 8592, 47395, 3215,
                                 9957, 44049, 19986, 51664], 'temperature': 0.0, 'avg_logprob': -0.26228470770304635,
                      'compression_ratio': 1.841860465116279, 'no_speech_prob': 0.3708573281764984},
                     {'id': 13, 'seek': 0, 'start': 26.0, 'end': 28.0, 'text': ' تافه',
                      'tokens': [51664, 6055, 31845, 3224, 51764], 'temperature': 0.0,
                      'avg_logprob': -0.26228470770304635, 'compression_ratio': 1.841860465116279,
                      'no_speech_prob': 0.3708573281764984},
                     {'id': 14, 'seek': 2800, 'start': 28.0, 'end': 30.0, 'text': ' نعم آه',
                      'tokens': [50364, 8717, 25957, 19753, 3224, 50464], 'temperature': 0.0,
                      'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 15, 'seek': 2800, 'start': 30.0, 'end': 32.0, 'text': ' كيرو الحبوب في مزارعنا',
                      'tokens': [50464, 9122, 13546, 2407, 21542, 3555, 37746, 8978, 3714, 11622, 9640, 3615, 8315,
                                 50564], 'temperature': 0.0, 'avg_logprob': -0.1553307568585431,
                      'compression_ratio': 1.8153846153846154, 'no_speech_prob': 0.23214995861053467},
                     {'id': 16, 'seek': 2800, 'start': 32.0, 'end': 34.0, 'text': ' هي الذهب الحقيقي',
                      'tokens': [50564, 39896, 32545, 3224, 3555, 21542, 38436, 38436, 50664], 'temperature': 0.0,
                      'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 17, 'seek': 2800, 'start': 34.0, 'end': 36.0, 'text': ' والعاملون حسناً',
                      'tokens': [50664, 16070, 3615, 10943, 1211, 11536, 11331, 3794, 8315, 14111, 50764],
                      'temperature': 0.0, 'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 18, 'seek': 2800, 'start': 36.0, 'end': 38.0, 'text': ' هم أهم شيء',
                      'tokens': [50764, 8032, 2304, 5551, 16095, 44049, 38207, 50864], 'temperature': 0.0,
                      'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 19, 'seek': 2800, 'start': 38.0, 'end': 40.0, 'text': ' أمي رجاءً أهم شيء لي هو',
                      'tokens': [50864, 5551, 2304, 1829, 12602, 7435, 16606, 14111, 5551, 16095, 44049, 38207, 32239,
                                 31439, 50964], 'temperature': 0.0, 'avg_logprob': -0.1553307568585431,
                      'compression_ratio': 1.8153846153846154, 'no_speech_prob': 0.23214995861053467},
                     {'id': 20, 'seek': 2800, 'start': 40.0, 'end': 42.0, 'text': ' آه',
                      'tokens': [50964, 19753, 3224, 51064], 'temperature': 0.0, 'avg_logprob': -0.1553307568585431,
                      'compression_ratio': 1.8153846153846154, 'no_speech_prob': 0.23214995861053467},
                     {'id': 21, 'seek': 2800, 'start': 44.0, 'end': 46.0, 'text': ' هذه دعوة عشاء الملك',
                      'tokens': [51164, 29538, 11778, 3615, 2407, 3660, 6225, 8592, 16606, 9673, 23275, 51264],
                      'temperature': 0.0, 'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 22, 'seek': 2800, 'start': 46.0, 'end': 48.0, 'text': ' أوه أحتاج ملابس جديدة',
                      'tokens': [51264, 34051, 3224, 5551, 33753, 26108, 3714, 15040, 3555, 3794, 10874, 16254, 41891,
                                 51364], 'temperature': 0.0, 'avg_logprob': -0.1553307568585431,
                      'compression_ratio': 1.8153846153846154, 'no_speech_prob': 0.23214995861053467},
                     {'id': 23, 'seek': 2800, 'start': 48.0, 'end': 50.0, 'text': ' وكفا',
                      'tokens': [51364, 4032, 4117, 5172, 995, 51464], 'temperature': 0.0,
                      'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 24, 'seek': 2800, 'start': 50.0, 'end': 52.0, 'text': ' روشي لقد دللناك',
                      'tokens': [51464, 12602, 2407, 8592, 1829, 5296, 28543, 11778, 1211, 1211, 8315, 4117, 51564],
                      'temperature': 0.0, 'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 25, 'seek': 2800, 'start': 52.0, 'end': 54.0, 'text': ' كثيراً لن تأتي',
                      'tokens': [51564, 9122, 12984, 13546, 995, 14111, 5296, 1863, 6055, 10721, 31371, 51664],
                      'temperature': 0.0, 'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 26, 'seek': 2800, 'start': 54.0, 'end': 56.0, 'text': ' العشاء الملك معنا',
                      'tokens': [51664, 18863, 8592, 16606, 9673, 23275, 20449, 8315, 51764], 'temperature': 0.0,
                      'avg_logprob': -0.1553307568585431, 'compression_ratio': 1.8153846153846154,
                      'no_speech_prob': 0.23214995861053467},
                     {'id': 27, 'seek': 5600, 'start': 56.0, 'end': 58.0, 'text': ' لماذا',
                      'tokens': [50364, 32767, 45636, 995, 50464], 'temperature': 0.0,
                      'avg_logprob': -0.22577791213989257, 'compression_ratio': 1.0606060606060606,
                      'no_speech_prob': 0.0107549037784338},
                     {'id': 28, 'seek': 5600, 'start': 58.0, 'end': 60.0, 'text': ' كيرو الحبوب',
                      'tokens': [50464, 9122, 13546, 2407, 21542, 3555, 37746, 50564], 'temperature': 0.0,
                      'avg_logprob': -0.22577791213989257, 'compression_ratio': 1.0606060606060606,
                      'no_speech_prob': 0.0107549037784338},
                     {'id': 29, 'seek': 5600, 'start': 60.0, 'end': 62.0, 'text': ' لقد فكرنا لبعض الوقت',
                      'tokens': [50564, 5296, 28543, 6156, 37983, 8315, 5296, 3555, 3615, 11242, 2423, 2407, 149, 224,
                                 2655, 50664], 'temperature': 0.0, 'avg_logprob': -0.22577791213989257,
                      'compression_ratio': 1.0606060606060606, 'no_speech_prob': 0.0107549037784338}], 'language': 'ar'}

"""